@@ -1,6 +1,6 @@
 package Dist::Zilla::PluginBundle::RJBS;
 # ABSTRACT: BeLike::RJBS when you build your dists
-$Dist::Zilla::PluginBundle::RJBS::VERSION = '5.009';
+$Dist::Zilla::PluginBundle::RJBS::VERSION = '5.010';
 use Moose;
 use Dist::Zilla 2.100922; # TestRelease
 with 'Dist::Zilla::Role::PluginBundle::Easy';
@@ -85,7 +85,8 @@ has github_issues => (
 has homepage => (
   is      => 'ro',
   isa     => 'Str',
-  predicate => 'has_homepage',
+  lazy    => 1,
+  default => sub { $_[0]->payload->{homepage} // '' },
 );
 
 has weaver_config => (
@@ -104,6 +105,13 @@ has dont_compile => (
   default => sub { $_[0]->payload->{dont_compile} || [] },
 );
 
+has package_name_version => (
+  is      => 'ro',
+  isa     => 'Bool',
+  lazy    => 1,
+  default => sub { $_[0]->payload->{package_name_version} // 0 },
+);
+
 sub configure {
   my ($self) = @_;
 
@@ -159,6 +167,7 @@ sub configure {
       PkgVersion => {
         die_on_existing_version => 1,
         die_on_line_insertion   => 1,
+        ($self->package_name_version ? (use_package => 1) : ()),
       },
     ],
     qw(
@@ -194,7 +203,7 @@ sub configure {
     [ GithubMeta => {
       remote => [ qw(github origin) ],
       issues => $self->github_issues,
-      ($self->has_homepage ? (homepage => $self->homepage) : ()),
+      (length $self->homepage ? (homepage => $self->homepage) : ()),
     } ],
   );
 
@@ -226,7 +235,7 @@ Dist::Zilla::PluginBundle::RJBS - BeLike::RJBS when you build your dists
 
 =head1 VERSION
 
-version 5.009
+version 5.010
 
 =head1 DESCRIPTION
 
@@ -283,7 +292,7 @@ Karen Etheridge <ether@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2015 by Ricardo Signes.
+This software is copyright (c) 2016 by Ricardo Signes.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
